@@ -98,6 +98,8 @@ Board::Board(QWidget *parent, const char *name, QCanvas* c)
   
 	updateCaption();
 	gatter_created = false;
+	
+	isHidingStones = false; // QQQ
 }
 
 Board::~Board()
@@ -456,6 +458,32 @@ void Board::drawStarPoint(int x, int y)
     }
 }
 
+void Board::hideStones()  // QQQ
+{
+    isHidingStones ^= true;
+    QIntDict<Stone>* stones = boardHandler->getStoneHandler()->getAllStones();
+    if (stones->isEmpty())
+        return;
+    
+    QIntDictIterator<Stone> it(*stones);
+    Stone *s;
+    while (s = it.current()) {
+        if (isHidingStones) {
+	    s->setFrame(1+WHITE_STONES_NB+1);
+	    s->shadow->setFrame(1+WHITE_STONES_NB+1);
+        }
+        else {
+	    if (boardHandler->getGameData()->oneColorGo)
+	        s->setFrame((rand() % 8) + 1);
+	    else
+	        s->setFrame(s->getColor() == stoneBlack ? 0 : (rand() % 8) + 1);
+	    s->shadow->setFrame(1+WHITE_STONES_NB);
+        }
+        ++it;
+    }
+    updateCanvas();
+}
+
 Stone* Board::addStoneSprite(StoneColor c, int x, int y, bool &shown)
 {
     if (x < 1 || x > board_size || y < 1 || y > board_size)
@@ -487,8 +515,17 @@ Stone* Board::addStoneSprite(StoneColor c, int x, int y, bool &shown)
 			
  			Stone *s = new Stone(imageHandler->getStonePixmaps(), canvas, c, x, y,WHITE_STONES_NB,true);
 			
-			if (boardHandler->getGameData()->oneColorGo)
-				s->toggleOneColorGo(true);
+			if (isHidingStones) { // QQQ
+				s->setFrame(1+WHITE_STONES_NB+1);
+				s->shadow->setFrame(1+WHITE_STONES_NB+1);
+			}
+			else {
+				if (boardHandler->getGameData()->oneColorGo)
+				    s->toggleOneColorGo(true);
+				else
+				    s->setFrame(c == stoneBlack ? 0 : (rand() % 8) + 1);
+				s->shadow->setFrame(1+WHITE_STONES_NB);
+			}
               
 			CHECK_PTR(s);
 			
@@ -641,7 +678,7 @@ void Board::contentsWheelEvent(QWheelEvent *e)
 		return;
 	
     // Needs an extra check on variable mouseState as state() does not work on Windows.
-    if (e->delta() == 120)
+    if (e->delta() != 120) // QQQ weel down to next
     {
 		if (e->state() == RightButton || mouseState == RightButton)
 			nextVariation();
@@ -1258,13 +1295,16 @@ void Board::updateLastMove(StoneColor c, int x, int y)
 		removeLastMoveMark();
 	else if (c != stoneNone && x != -1 && y != -1 && x <= board_size && y <= board_size)
 	{
-//		lastMoveMark = new MarkText(imageHandler, x, y, square_size, "+", canvas,
-		// true = plus sign
-		lastMoveMark = new MarkCross(x, y, square_size, canvas,
-			c == stoneBlack ? white : black, true);
+		if (isHidingStones)
+			lastMoveMark = new MarkRedCircle(x, y, square_size, canvas,
+				c == stoneBlack ? white : black, true); // QQQ
+		else
+			lastMoveMark = new MarkCross(x, y, square_size, canvas,
+				c == stoneBlack ? white : black, true);
+
+
 		ASSERT(lastMoveMark);
-//		lastMoveMark = new MarkCircle(x, y, square_size, canvas,
-//			c == stoneBlack ? white : black, setting->readBoolEntry("SMALL_STONES"));
+
 		lastMoveMark->setX(offsetX + square_size * (x-1) - lastMoveMark->getSizeX()/2);
 		lastMoveMark->setY(offsetY + square_size * (y-1) - lastMoveMark->getSizeY()/2);
 		lastMoveMark->show();
@@ -1403,20 +1443,24 @@ void Board::setShowSGFCoords(bool b)
 
 void Board::initGame(GameData *d, bool sgf)
 {
-    CHECK_PTR(d);
+	CHECK_PTR(d);
 	
-    int oldsize = board_size;
-    board_size = d->size;
+	int oldsize = board_size;
+	board_size = d->size;
 	
-    // Clear up everything
-    clearData();
+	// Clear up everything
+	clearData();
 	
-    // Different board size? Redraw the canvas.
-    if (board_size != oldsize)
+	// Different board size? Redraw the canvas.
+	if (board_size != oldsize)
+	{
+		delete gatter;
+		gatter = new Gatter(canvas, board_size);	
 		changeSize();
-    
-    boardHandler->initGame(d, sgf);
-    updateCaption();
+	}
+
+	boardHandler->initGame(d, sgf);
+	updateCaption();
 }
 
 void Board::setModified(bool m)
@@ -1719,6 +1763,37 @@ Gatter::Gatter(QCanvas *Canvas, int size)
 	showAll();
 }
 
+
+ /**
+ * Destroys the gatter
+ **/
+Gatter::~Gatter()
+{
+	int i,j; 
+
+
+	for (i=0; i<board_size; i++)
+ 	{
+		for (j=0; j<board_size; j++)
+ 		{
+ 			delete VGatter[i][j];
+			delete HGatter[i][j];
+		} 
+	VGatter[i].clear();
+	HGatter[i].clear();	
+	}
+
+	VGatter.clear();	
+	HGatter.clear();
+
+	QIntDictIterator<QCanvasEllipse> it( hoshisList );
+	for ( ; it.current(); ++it )
+        	delete it.current(); 
+
+}
+
+
+
  /**
  * Calculates the gatter intersections and hoshis position
  **/
