@@ -132,6 +132,7 @@ public:
 	bool exportSGFtoClipB() { return boardHandler->exportSGFtoClipB(); }
 	void countScore();
 	void doCountDone();
+	void hideStones(); // QQQ
 	void numberMoves() { boardHandler->numberMoves(); }
 	void markVariations(bool sons) { boardHandler->markVariations(sons); }
 	void setBoardSize(int s) { board_size = s; }
@@ -213,6 +214,8 @@ private:
 	QTime wheelTime;
 	ButtonState mouseState;
 	NodeResults *nodeResultsDlg;
+	
+	bool isHidingStones; // QQQ
 
 #ifdef Q_WS_WIN
 	bool resizeDelayFlag;
