@@ -58,8 +58,10 @@ BoardHandler::BoardHandler(Board *b)
 	nodeResults = NULL;
 	gtp = NULL;
 
-  // Assume we display events (incoming move when observing)
-  display_incoming_move = true ;  //SL added eb 9
+  	// Assume we display events (incoming move when observing)
+  	display_incoming_move = true ;
+
+	local_stone_sound = setting->readBoolEntry("SOUND_STONE");
 }
 
 BoardHandler::~BoardHandler()
@@ -253,12 +255,12 @@ void BoardHandler::addStone(StoneColor c, int x, int y, bool sound)
 		currentMove++;
 		if (setting->readIntEntry("VAR_GHOSTS"))
 			board->removeGhosts();
-		addMove(c, x, y);                    //SL abb eb 8
-		if (sound)
+		addMove(c, x, y);
+		if (sound && local_stone_sound)
 			setting->qgo->playClick();
 
-	if (!do_not_show)                       //SL add eb 8
-		board->updateLastMove(c,x,y);        //SL add eb 8
+	if (!do_not_show)                       
+		board->updateLastMove(c,x,y);       
 	}
 	// Edit mode...
 	else if (gameMode == modeEdit)
