@@ -36,28 +36,38 @@
 /*
 * Set available languages here. The Codes have to be in the same order as the language names
 */
-#define NUMBER_OF_AVAILABLE_LANGUAGES 9
+#define NUMBER_OF_AVAILABLE_LANGUAGES 11
 #define AVAILABLE_LANGUAGES { \
 	"Chinese", \
+	"Chinese (simplified)", \
 	"Czech", \
 	"Danish", \
 	"Deutsch", \
 	"English", \
+	"Espanol",\
 	"Franais", \
 	"Italiano", \
+	"Latin (!)", \
 	"Nederlands", \
-	"Portuges"}
+	"Portuges", \
+	"Russian", \
+	"Trke"}
 	
 #define LANGUAGE_CODES { \
 	"zh", \
+	"zh_cn", \
 	"cz", \
 	"dk", \
 	"de", \
 	"en", \
+	"es",\
 	"fr", \
 	"it", \
+	"la", \
 	"nl", \
-	"pt"}
+	"pt", \
+	"ru", \
+	"tr"}
 
 
 /*
