@@ -64,8 +64,8 @@ bool IGSConnection::checkPrompt()
 			{
 				qsocket->waitForMore(500);
 				b = qsocket->bytesAvailable();
-				if (!b)
-					return false;
+//				if (!b)
+//					return false;
 			}
 
 			while (b-- > 0)
@@ -305,7 +305,7 @@ bool IGSConnection::openConnection(const char *host, unsigned int port, const ch
 	password = pass;
 	
 	qDebug("Connecting to %s %d as [%s], [%s]...", host, port, username.latin1(), (password ? "***" : "NULL"));
-	sendTextToApp(tr("Trying to connect to") + " " + QString(host) + " " + QString::number(port));
+	sendTextToApp(tr("Trying to connect to %1 %2").arg(host,port));
 
 	ASSERT(host != 0);
 	ASSERT(port != 0);
