@@ -12,6 +12,8 @@
 #include <qsocket.h>
 #include <qstring.h>
 
+class QTextCodec;
+
 #define MAX_LINESIZE 512
 
 class IGSConnection : public QObject, public IGSInterface
@@ -24,14 +26,16 @@ public:
 
 	// Implementation of IGSInterface virtual functions
 	virtual bool isConnected();
-	virtual bool openConnection(const char *host, unsigned port,
-								const char *user=0, const char *pass=0);
+	virtual bool openConnection(const char *host, unsigned port, const char *user=0, const char *pass=0);
+
 	virtual bool closeConnection();
-	virtual void sendTextToHost(const char *txt);
-	virtual void sendTextToHost(QString *txt);
+	virtual void sendTextToHost(QString txt, bool ignoreCodec=false);
 	
 	virtual const char* getUsername();
 
+	virtual void setTextCodec(QString codec);
+
+
 signals:
 	// for statistics reason
 	void signal_setBytesIn(int);
@@ -41,10 +45,7 @@ protected:
 	virtual bool checkPrompt();
 //	void convertBlockToLines();
 	
-	void sendTextToApp(const char *txt, unsigned int size);
-	void sendTextToApp(const char *s);
-	void sendTextToApp(QString *txt);
-	void sendTextToApp(QCString *txt);
+	void sendTextToApp(QString txt);
 
 private slots:
 	void OnHostFound();
@@ -57,6 +58,7 @@ private slots:
 
 private:
 	QSocket *qsocket;
+	QTextCodec *textCodec;
 
 	//struct USERINFO {
 	QString username;
