@@ -52,6 +52,7 @@ GameMode InterfaceHandler::toggleMode()
 		board->setMode(modeNormal);
 //		modeButton->setEnabled(true);
 		mainWidget->setToolsTabWidget(tabEdit, tabEnable);
+		mainWidget->setToolsTabWidget(tabTeachGameTree, tabDisable);
 		scoreButton->setEnabled(true);
 		scoreButton->setText(QObject::tr("Score", "button label"));
 		passButton->setEnabled(true);
@@ -70,6 +71,7 @@ GameMode InterfaceHandler::toggleMode()
 		board->setMode(modeEdit);
 //		modeButton->setEnabled(true);
 		mainWidget->setToolsTabWidget(tabEdit, tabEnable);
+		mainWidget->setToolsTabWidget(tabTeachGameTree, tabDisable);
 		scoreButton->setDisabled(true);
 		scoreButton->setText(QObject::tr("Score", "button label"));
 		passButton->setDisabled(true);
@@ -88,6 +90,7 @@ GameMode InterfaceHandler::toggleMode()
 		board->setMode(modeObserve);
 //		modeButton->setDisabled(true);
 		mainWidget->setToolsTabWidget(tabEdit, tabDisable);
+		mainWidget->setToolsTabWidget(tabTeachGameTree, tabDisable);
 		scoreButton->setEnabled(true);
 		scoreButton->setText(QObject::tr("Edit", "button label"));
 		passButton->setDisabled(true);
@@ -111,6 +114,7 @@ GameMode InterfaceHandler::toggleMode()
 		board->setMode(modeMatch);
 //		modeButton->setDisabled(true);
 		mainWidget->setToolsTabWidget(tabEdit, tabDisable);
+		mainWidget->setToolsTabWidget(tabTeachGameTree, tabDisable);
 		scoreButton->setEnabled(true);
 		scoreButton->setText(QObject::tr("Edit", "button label"));
 		passButton->setEnabled(true);
@@ -133,6 +137,7 @@ GameMode InterfaceHandler::toggleMode()
 		board->setMode(modeComputer);
 //		modeButton->setDisabled(true);
 		mainWidget->setToolsTabWidget(tabEdit, tabDisable);
+		mainWidget->setToolsTabWidget(tabTeachGameTree, tabDisable);
 		scoreButton->setEnabled(true);
 		scoreButton->setText(QObject::tr("Edit", "button label"));
 		passButton->setEnabled(true);
@@ -155,6 +160,7 @@ GameMode InterfaceHandler::toggleMode()
 		board->setMode(modeTeach);
 //		modeButton->setDisabled(true);
 		mainWidget->setToolsTabWidget(tabEdit, tabDisable);
+		mainWidget->setToolsTabWidget(tabTeachGameTree, tabEnable);
 		scoreButton->setEnabled(true);
 		scoreButton->setText(QObject::tr("Edit", "button label"));
 		passButton->setEnabled(true);
