@@ -24,7 +24,7 @@
 #include <qlistview.h>
 #include <qcheckbox.h>
 #include <qtextstream.h>
-#include <qtextview.h>
+#include <qtextedit.h>
 #include <qstring.h>
 #include <qobject.h>
 
@@ -37,7 +37,7 @@
 Setting *setting = 0;
 
 #ifdef OWN_DEBUG_MODE
-QTextView *view;
+QTextEdit *view =0 ;
 #endif
 
 /*
@@ -46,9 +46,9 @@ QTextView *view;
 
 int main(int argc, char **argv)
 {
-#ifdef OWN_DEBUG_MODE
-	qInstallMsgHandler(myMessageHandler);
-#endif
+//#ifdef OWN_DEBUG_MODE
+//	qInstallMsgHandler(myMessageHandler);
+//#endif
 
 	bool found_debug = false;
 	bool found_sgf = false;
@@ -96,10 +96,13 @@ int main(int argc, char **argv)
 	QString style =  myapp.style().name();
   
 #ifdef OWN_DEBUG_MODE
+	qInstallMsgHandler(myMessageHandler);
 	Debug_Dialog *nonModal = new Debug_Dialog();
 	view = nonModal->TextView1;
 #endif
+	
 
+	
 	// get application path
 	QFileInfo program(argv[0]);
 	QString program_dir = program.dirPath(true);
