@@ -17,10 +17,10 @@
 #include <qlineedit.h>
 #include <qtabwidget.h>
 
-#ifdef USE_XPM
+//#ifdef USE_XPM
 #include ICON_NODE_BLACK
 #include ICON_NODE_WHITE
-#endif
+//#endif
 
 /* 
 *  Constructs a MainWidget which is a child of 'parent', with the 
@@ -116,19 +116,19 @@ void MainWidget::slot_toolsTabChanged(QWidget * /*w*/)
 			// set color of next move
 			if (interfaceHandler->board->getBoardHandler()->getBlackTurn())
 			{
-#ifndef USE_XPM
-				colorButton->setPixmap(QPixmap(ICON_NODE_BLACK));
-#else
+//#ifndef USE_XPM
+//				colorButton->setPixmap(QPixmap(ICON_NODE_BLACK));
+//#else
 				colorButton->setPixmap(QPixmap(const_cast<const char**>(node_black_xpm)));
-#endif
+//#endif
 			}
 			else
 			{
-#ifndef USE_XPM
-				colorButton->setPixmap(QPixmap(ICON_NODE_WHITE));
-#else
+//#ifndef USE_XPM
+//				colorButton->setPixmap(QPixmap(ICON_NODE_WHITE));
+//#else
 				colorButton->setPixmap(QPixmap(const_cast<const char**>(node_white_xpm)));
-#endif
+//#endif
 			}
 
 			interfaceHandler->toggleMode();
