@@ -972,10 +972,11 @@ void ClientWindow::sendTextToApp(const QString &txt)
 //					if (setting->readBoolEntry("USE_NMATCH"))
 //					{
 // we wanted to allow user to disable 'nmatch', but IGS disables 'seek' with nmatch
-						sendcommand("toggle nmatch");
+					set_sessionparameter("nmatch",true);
 
 						//temporaary settings to prevent use of Koryo BY on IGS (as opposed to canadian)
-						sendcommand("nmatchrange BWN 0-9 19-19 60-60 60-3600 25-25 0 0 0-0",false);
+						//sendcommand("nmatchrange BWN 0-9 19-19 60-60 60-3600 25-25 0 0 0-0",false);
+					send_nmatch_range_parameters();
 //					}
 					sendcommand("toggle newundo");
 					sendcommand("toggle seek");
@@ -1940,7 +1941,19 @@ void ClientWindow::slot_matchrequest(const QString &line, bool myrequest)
 			dlg->buttonOffer->setText(tr("Teaching"));
 
 		//nmatch settings from opponent 
-		bool is_nmatch = (lv_popupPlayer->nmatch)&&setting->readBoolEntry("USE_NMATCH");
+		bool is_nmatch = false;
+
+		// we want to make sure the player is selected, because the match request may come from an other command (match button on the tab dialog)
+		QString lv_popup_name ;
+
+		if (lv_popupPlayer )
+		{
+			lv_popup_name = (lv_popupPlayer->text(1).right(1) == "*" ? lv_popupPlayer->text(1).left( lv_popupPlayer->text(1).length() -1 ):lv_popupPlayer->text(1));
+		
+
+			is_nmatch = ((lv_popupPlayer->nmatch ) &&  (lv_popup_name == opponent));// && setting->readBoolEntry("USE_NMATCH");
+		}
+
 		dlg->set_is_nmatch(is_nmatch);
 
 		if ( (is_nmatch) && (lv_popupPlayer->nmatch_settings ))
@@ -1956,8 +1969,8 @@ void ClientWindow::slot_matchrequest(const QString &line, bool myrequest)
 			dlg->handicapSpin->setRange(0,9);
 		}
 		//no handicap with usual game requests
-		dlg->handicapSpin->setEnabled(lv_popupPlayer->nmatch);
-		dlg->play_nigiri_button->setEnabled(lv_popupPlayer->nmatch);
+		dlg->handicapSpin->setEnabled(is_nmatch);
+		dlg->play_nigiri_button->setEnabled(is_nmatch);
 
 		//default settings
 		dlg->boardSizeSpin->setValue(setting->readIntEntry("DEFAULT_SIZE"));
@@ -2999,7 +3012,7 @@ void ClientWindow::slotFileOpen()
 	//if (!checkModified())
 	//	return;
 	QString fileName(QFileDialog::getOpenFileName(setting->readEntry("LAST_DIR"),
-		tr("SGF Files (*.sgf);;MGT Files (*.mgt);;XML Files (*.xml);;All Files (*)"), this));
+		tr("SGF Files (*.sgf *.SGF);;MGT Files (*.mgt);;XML Files (*.xml);;All Files (*)"), this));
 	if (fileName.isEmpty())
 		return;
 
@@ -3264,3 +3277,35 @@ void ClientWindow::slot_SeekList(const QString& player, const QString& condition
 
 	slot_message(player.leftJustify(15,' ',true) + Rk.rightJustify(5) +  " : " + condition);
 }
+
+/*
+* on IGS, sends the 'nmatch'time, BY, handicap ranges
+* command syntax : "nmatchrange 	BWN 	0-9 19-19	 60-60 		60-3600 	25-25 		0 0 0-0"
+*				(B/W/ nigiri)	Hcp Sz	   Main time (secs)	BY time (secs)	BY stones	Koryo time
+*/
+void ClientWindow::send_nmatch_range_parameters()
+{
+	
+	if ((myAccount->get_gsname() != IGS) || (myAccount->get_status() == OFFLINE))
+		return ;
+
+	QString c = "nmatchrange ";
+	c.append(setting->readBoolEntry("NMATCH_BLACK") ? "B" : "");
+	c.append(setting->readBoolEntry("NMATCH_WHITE") ? "W" : "");
+	c.append(setting->readBoolEntry("NMATCH_NIGIRI") ? "N" : "");
+	c.append(" 0-");
+	c.append(QString::number(setting->readIntEntry("NMATCH_HANDICAP")));
+	c.append(" ");
+	c.append(QString::number(setting->readIntEntry("DEFAULT_SIZE")));
+	c.append("-19 ");
+	c.append(QString::number(setting->readIntEntry("DEFAULT_TIME")*60));
+	c.append("-");
+	c.append(QString::number(setting->readIntEntry("NMATCH_MAIN_TIME")*60));
+	c.append(" ");
+	c.append(QString::number(setting->readIntEntry("DEFAULT_BY")*60));
+	c.append("-");
+	c.append(QString::number(setting->readIntEntry("NMATCH_BYO_TIME")*60));
+	c.append(" 25-25 0 0 0-0");
+	
+	sendcommand(c, true);
+}
\ No newline at end of file
