@@ -4,6 +4,7 @@
 
 #include "misc.h"
 #include "qgo.h"
+#include "mainwin.h"
 #include "mainwindow.h"
 #include "mainwidget.h"
 #include "board.h"
@@ -311,6 +312,7 @@ MainWindow::~MainWindow()
 	delete editPaste;
 	delete editPasteBrother;
 	delete editDelete;
+	delete editHideStones; //QQQ
 	delete editNumberMoves;
 	delete editMarkBrothers;
 	delete editMarkSons;
@@ -580,6 +582,13 @@ void MainWindow::initActions()
 	editDelete->setWhatsThis(tr("Delete\n\nDelete this and all following positions."));
 	connect(editDelete, SIGNAL(activated()), this, SLOT(slotEditDelete()));
 	
+	// QQQ Toggle Hide Stones
+	editHideStones = new QAction(tr("Toggle Hiding"), tr("Toggle &Hiding"),
+		QAccel::stringToKey(tr("Alt+F2")), this);
+	editHideStones->setStatusTip(tr("Toggle to Hide all Stones in the board."));
+	editHideStones->setWhatsThis(tr("Toggle to Hide Stones\n\nToggle to Hide all Stones in the board."));
+	connect(editHideStones, SIGNAL(activated()), this, SLOT(slotEditHideStones()));
+	
 	// Edit number moves
 	editNumberMoves = new QAction(tr("Number Moves"), tr("&Number Moves"),
 		QAccel::stringToKey(tr("Shift+F2")), this);
@@ -948,6 +957,7 @@ void MainWindow::initMenuBar()
 	editPasteBrother->addTo(editMenu);
 	editDelete->addTo(editMenu);
 	editMenu->insertSeparator();
+	editHideStones->addTo(editMenu); //QQQ
 	editNumberMoves->addTo(editMenu);
 	editMarkBrothers->addTo(editMenu);
 	editMarkSons->addTo(editMenu);
@@ -1192,7 +1202,7 @@ void MainWindow::slotFileOpen()
 	if (!checkModified())
 		return;
 	QString fileName(QFileDialog::getOpenFileName(setting->readEntry("LAST_DIR"),
-		tr("SGF Files (*.sgf);;MGT Files (*.mgt);;XML Files (*.xml);;All Files (*)"), this));
+		tr("SGF Files (*.sgf *.SGF);;MGT Files (*.mgt);;XML Files (*.xml);;All Files (*)"), this));
 	if (fileName.isEmpty())
 		return;
 	doOpen(fileName, getFileExtension(fileName));
@@ -1438,6 +1448,11 @@ void MainWindow::slotEditDelete()
 	board->deleteNode();
 }
 
+void MainWindow::slotEditHideStones() // QQQ
+{
+	board->hideStones();
+}
+
 void MainWindow::slotEditNumberMoves()
 {
 	board->numberMoves();
@@ -1599,8 +1614,12 @@ void MainWindow::dlgSetPreferences(int tab)
 	dlg.languageComboBox->insertStringList(setting->getAvailableLanguages());
 	dlg.languageComboBox->setCurrentItem(setting->convertLanguageCodeToNumber());
 	dlg.commentComboBox->setCurrentItem(setting->readIntEntry("VIEW_COMMENT"));
-	dlg.stonesShadowCheckBox->setChecked(setting->readBoolEntry("STONES_SHADOW"));
-	dlg.stonesShellsCheckBox->setChecked(setting->readBoolEntry("STONES_SHELLS"));
+//	dlg.stonesShadowCheckBox->setChecked(setting->readBoolEntry("STONES_SHADOW"));
+	dlg.radioButtonStones_2D->setChecked((setting->readIntEntry("STONES_LOOK")==1));
+	dlg.radioButtonStones_3D->setChecked((setting->readIntEntry("STONES_LOOK")==2));
+	dlg.radioButtonStone_real->setChecked((setting->readIntEntry("STONES_LOOK")==3));
+
+//	dlg.stonesShellsCheckBox->setChecked(setting->readBoolEntry("STONES_SHELLS"));
 	dlg.stoneSoundCheckBox->setChecked(setting->readBoolEntry("SOUND_STONE"));
 	dlg.autoplaySoundCheckBox->setChecked(setting->readBoolEntry("SOUND_AUTOPLAY"));
 	dlg.talkSoundCheckBox->setChecked(setting->readBoolEntry("SOUND_TALK"));
@@ -1652,6 +1671,13 @@ void MainWindow::dlgSetPreferences(int tab)
 	dlg.LineEdit_exclude->setText(setting->readEntry("EXCLUDE"));
 	dlg.CheckBox_extUserInfo->setChecked(setting->readBoolEntry("EXTUSERINFO"));
 //	dlg.CheckBox_useNmatch->setChecked(setting->readBoolEntry("USE_NMATCH"));
+	dlg.checkBox_Nmatch_Black->setChecked(setting->readBoolEntry("NMATCH_BLACK"));
+	dlg.checkBox_Nmatch_White->setChecked(setting->readBoolEntry("NMATCH_WHITE"));
+	dlg.checkBox_Nmatch_Nigiri->setChecked(setting->readBoolEntry("NMATCH_NIGIRI"));
+	dlg.HandicapSpin_Nmatch->setValue(setting->readIntEntry("NMATCH_HANDICAP"));	
+	dlg.timeSpin_Nmatch->setValue(setting->readIntEntry("NMATCH_MAIN_TIME"));
+	dlg.BYSpin_Nmatch->setValue(setting->readIntEntry("NMATCH_BYO_TIME"));
+
 	dlg.LineEdit_computer->setText(setting->readEntry("COMPUTER_PATH")); //SL added eb 12
 	dlg.computerButtonWhite->setChecked(setting->readBoolEntry("COMPUTER_WHITE"));
 	dlg.computerButtonBlack->setChecked(setting->readBoolEntry("COMPUTER_BLACK"));
@@ -1669,7 +1695,7 @@ void MainWindow::dlgSetPreferences(int tab)
 	dlg.komiSpinDefault->setValue(setting->readIntEntry("DEFAULT_KOMI"));
 	dlg.automaticNegotiationCheckBox->setChecked(setting->readBoolEntry("DEFAULT_AUTONEGO"));
 	dlg.CheckBox_autoSave->setChecked(setting->readBoolEntry("AUTOSAVE"));
-dlg.CheckBox_autoSave_Played->setChecked(setting->readBoolEntry("AUTOSAVE_PLAYED"));
+	dlg.CheckBox_autoSave_Played->setChecked(setting->readBoolEntry("AUTOSAVE_PLAYED"));
 	/*
 	// do some size changes
 	QSize qs = dlg.pb_add->minimumSizeHint();
@@ -1705,8 +1731,15 @@ bool MainWindow::preferencesSave(PreferencesDialog *dlg)
 	setting->writeEntry("SKIN_TABLE", dlg->LineEdit_Table->text()); 
 	setting->writeEntry("LANG", setting->convertNumberToLanguage(dlg->languageComboBox->currentItem()));
 	setting->writeIntEntry("VIEW_COMMENT", dlg->commentComboBox->currentItem());
-	setting->writeBoolEntry("STONES_SHADOW", dlg->stonesShadowCheckBox->isChecked());
-	setting->writeBoolEntry("STONES_SHELLS", dlg->stonesShellsCheckBox->isChecked());
+//	setting->writeBoolEntry("STONES_SHADOW", dlg->stonesShadowCheckBox->isChecked());
+//	setting->writeBoolEntry("STONES_SHELLS", dlg->stonesShellsCheckBox->isChecked());
+	int i = 3;
+	if ( dlg->radioButtonStones_2D->isChecked())
+		i=1;
+	else if ( dlg->radioButtonStones_3D->isChecked())
+		i=2;
+	setting->writeIntEntry("STONES_LOOK", i);
+
 	setting->writeBoolEntry("SOUND_STONE", dlg->stoneSoundCheckBox->isChecked());
 	setting->writeBoolEntry("SOUND_AUTOPLAY", dlg->autoplaySoundCheckBox->isChecked());
 	setting->writeBoolEntry("SOUND_TALK", dlg->talkSoundCheckBox->isChecked());
@@ -1753,6 +1786,27 @@ bool MainWindow::preferencesSave(PreferencesDialog *dlg)
 	setting->writeEntry("EXCLUDE", dlg->LineEdit_exclude->text());
 	setting->writeBoolEntry("EXTUSERINFO", dlg->CheckBox_extUserInfo->isChecked());
 //	setting->writeBoolEntry("USE_NMATCH", dlg->CheckBox_useNmatch->isChecked());
+
+	//Checks wether the nmatch parameters have been modified, in order to send a new nmatchrange command
+	if( 	(setting->readBoolEntry("NMATCH_BLACK") != dlg->checkBox_Nmatch_Black->isChecked()) || 
+		(setting->readBoolEntry("NMATCH_WHITE") != dlg->checkBox_Nmatch_White->isChecked()) ||
+		(setting->readBoolEntry("NMATCH_NIGIRI") != dlg->checkBox_Nmatch_Nigiri->isChecked()) ||
+		(setting->readIntEntry("NMATCH_MAIN_TIME") != dlg->timeSpin_Nmatch->text().toInt()) ||
+		(setting->readIntEntry("NMATCH_BYO_TIME") != dlg->BYSpin_Nmatch->text().toInt()) ||
+		(setting->readIntEntry("NMATCH_HANDICAP") != dlg->HandicapSpin_Nmatch->text().toInt()) ||
+		(setting->readIntEntry("DEFAULT_SIZE") != dlg->boardSizeSpin->text().toInt()) ||
+		(setting->readIntEntry("DEFAULT_TIME") != dlg->timeSpin->text().toInt()) ||
+		(setting->readIntEntry("DEFAULT_BY") != dlg->BYSpin->text().toInt()) )
+			setting->nmatch_settings_modified = true;
+
+	setting->writeBoolEntry("NMATCH_BLACK", dlg->checkBox_Nmatch_Black->isChecked());
+	setting->writeBoolEntry("NMATCH_WHITE", dlg->checkBox_Nmatch_White->isChecked());
+	setting->writeBoolEntry("NMATCH_NIGIRI", dlg->checkBox_Nmatch_Nigiri->isChecked());
+	setting->writeIntEntry("NMATCH_MAIN_TIME", dlg->timeSpin_Nmatch->text().toInt());
+	setting->writeIntEntry("NMATCH_BYO_TIME", dlg->BYSpin_Nmatch->text().toInt());
+	setting->writeIntEntry("NMATCH_HANDICAP", dlg->HandicapSpin_Nmatch->text().toInt());
+
+
 	setting->writeIntEntry("DEFAULT_SIZE", dlg->boardSizeSpin->text().toInt());
 	setting->writeIntEntry("DEFAULT_TIME", dlg->timeSpin->text().toInt());
 	setting->writeIntEntry("DEFAULT_BY", dlg->BYSpin->text().toInt());
@@ -1816,6 +1870,12 @@ bool MainWindow::preferencesAccept()
 	setting->qgo->updateAllBoardSettings();
 	setting->qgo->updateFont();
 	
+	if (setting->nmatch_settings_modified)
+	{
+		setting->cw->send_nmatch_range_parameters();
+		setting->nmatch_settings_modified = false ;
+	}
+
 	return true;//result;
 }
 
