@@ -4,12 +4,19 @@
 
 #include "msg_handler.h"
 
+
 #ifdef OWN_DEBUG_MODE
 void myMessageHandler(QtMsgType type, const char *msg)
 {
+	
+	if ((view == NULL) || (myapp.startingUp()) || (myapp.closingDown()))
+		return ;
+
+	//QString msg2 = QString::QString(msg);
+
 	switch (type)
 	{
-	case QtDebugMsg:		view->append((QString) "Debug: " + (QString) msg + (QString) "\n");
+	case QtDebugMsg:		view->append("Debug: "  + (QString) msg + "\n");
 		break;
 	case QtWarningMsg:	view->append((QString) "Warning: " + (QString) msg + (QString) "\n");
 		break;
