@@ -13,12 +13,13 @@
 
 
 #include <qapplication.h>
-#include <qtextview.h>
+#include <qtextedit.h>
 
 void myMessageHandler(QtMsgType, const char*);
 
 #ifdef OWN_DEBUG_MODE
-extern QTextView *view;
+extern QTextEdit *view;
+extern QApplication myapp;
 #endif
 
 #endif
