@@ -4,6 +4,7 @@
 
 #include "playertable.h"
 #include "misc.h"
+#include "setting.h"
 
 #include <qheader.h>
 #include <qvariant.h>
@@ -34,6 +35,20 @@ PlayerTable::PlayerTable(QWidget *parent, const char *name, bool /*modal*/, WFla
 	setAllColumnsShowFocus(true);
 }
 
+
+void PlayerTable::showOpen(bool show)
+{
+	QListViewItemIterator lv(this);
+	
+	for (; lv.current() ;lv++)
+	{
+		// player is not open or is playing a match
+		if ((lv.current()->text(0).contains('X')) || (!lv.current()->text(3).contains('-')))
+			lv.current()->setVisible(!show);
+		
+	}
+
+}
 /*
  *   PlayerTableItem
  */
@@ -101,12 +116,10 @@ PlayerTableItem::~PlayerTableItem()
 void PlayerTableItem::paintCell( QPainter *p, const QColorGroup &cg, int column, int width, int alignment )
 {
 	QColorGroup _cg( cg );
-//	QColor c = _cg.text();
 
-  //double i= itemPos()/height() ;
 
-  if (itemPos() % (2*height()))                 
-    _cg.setColor(QColorGroup::Base, cg.color(QColorGroup::Midlight));//QColor::QColor("AliceBlue")); 
+	if (itemPos() % (2*height()))
+		_cg.setColor(QColorGroup::Base, setting->colorAltBackground);//QColor::QColor(242,242,242,QColor::Rgb));//cg.color(QColorGroup::Midlight));//QColor::QColor("AliceBlue")); 
   
 	if (its_me)
 		_cg.setColor(QColorGroup::Text, Qt::blue);
@@ -121,7 +134,6 @@ void PlayerTableItem::paintCell( QPainter *p, const QColorGroup &cg, int column,
 
 	QListViewItem::paintCell(p, _cg, column, width, alignment);
 
-//	_cg.setColor(QColorGroup::Text, c);
 }
 
 void PlayerTableItem::ownRepaint()
@@ -150,118 +162,25 @@ int PlayerTableItem::compare(  QListViewItem *p, int col, bool ascending ) const
 }
 
 
-/* for correct sorting by rk and optionally txt
-QString PlayerTableItem::key(int column, bool ascending) const
+void PlayerTableItem::set_nmatchSettings(Player *p)
 {
-	switch (column)
-	{
-		// rank, however, considered to be most used...
-		case 2:
-			// return invisible column's text
-			return text(12);
+	nmatch = p->nmatch;
 
-			// correct message - but too slow
-			//return rkToKey(text(2)) + text(1).lower();
-			break;
+	nmatch_black = 		p->nmatch_black ;
+	nmatch_white = 		p->nmatch_white;
+	nmatch_nigiri = 	p->nmatch_nigiri ;
+	nmatch_handicapMin = 	p->nmatch_handicapMin;
+	nmatch_handicapMax  = 	p->nmatch_handicapMax;
+	nmatch_timeMin = 	p->nmatch_timeMin;
+	nmatch_timeMax  = 	p->nmatch_timeMax;
+	nmatch_BYMin = 		p->nmatch_BYMin;
+	nmatch_BYMax = 		p->nmatch_BYMax;
+	nmatch_stonesMin = 	p->nmatch_stonesMin;
+	nmatch_stonesMax = 	p->nmatch_stonesMax;
+	nmatch_KoryoMin = 	p->nmatch_KoryoMin;
+	nmatch_KoryoMax = 	p->nmatch_KoryoMax ;
 
-		// status: sort by "!" and -> rank!
-		case 0:
-		{
-			QString statStr;
+	nmatch_settings =  !(p->nmatch_settings == "No match conditions");
 
-			if (text(0).contains("!"))
-				statStr = "0" + text(0);
-			else
-				statStr = "1" + text(0);
-
-			return statStr + text(6);
-			// correct message - but too slow
-			// statStr + return rkToKey(text(2)) + text(1).lower();
-		}
-			break;
-
-		// name; second name: for correct sorting when two names are identical but uses lower & upper letters
-		case 1:
-			return text(column).lower() + text(column);
-			break;
-
-		// play, observe, won, lost
-		case 3:
-		case 4:
-		case 8:
-		case 9:
-			return text(column).stripWhiteSpace().rightJustify(3, '0');
-			break;
-
-		// idle
-		case 5:
-			return (text(5).contains("s") ? "A" : "B") + text(5).rightJustify(4, '0');
-
-		// watch entry
-		case 6:
-			if (text(6).length() == 0)
-				return ("Y" + text(12));
-			else if (text(6) == "X")
-				// excluded players at trailing
-				return ("Z" + text(12));
-			else
-				return (text(6) + text(12));
-
-		// ext. info, country, language
-		case 7:
-		case 10:
-		case 11:
-			// '{' == 'z' + 1, '@' = 'A' - 1
-			// if no text -> ensures that text(12) is at top/bottom
-			if (ascending)
-				return text(column).simplifyWhiteSpace() + '{' + text(12);
-			else
-				return text(column).simplifyWhiteSpace() + '@' + text(12);
-
-			break;
-
-		default:
-			return text(column);
-			break;
-	}
 }
 
-
-void PlayerTableItem::replace( )
-{	
-	bool ascending;
-	int sortColumn = listView()->sortColumn();
-
-	//don't sort if no sort column
-	if (sortColumn== -1)
-		return;
-		
-	QListViewItemIterator lv(this);
-	
-	// the current item has just been inserted. It should be at top of list
-	// the list as it was before starts with the second item
-	QListViewItem *lv_start = listView()->firstChild()->itemBelow();
-	
-	//if there was only 1 items in the list, there is no way to get the sorting order
-	if (lv_start && lv_start->itemBelow())
-		ascending=  (lv_start->itemBelow()->compare(lv_start->itemBelow()->itemBelow(), sortColumn, true) > 0);
-	else 
-		ascending = true;
-		
-	bool found = false;	
-	for (QListViewItem *lvi; lvi = lv++.current(); (lvi ==0) || found )
-	{
-		
-		if ((compare(lvi,sortColumn,ascending)*(ascending ? 1 : -1)) < 0) 
-			found=true;
-	}
-	
-	if (found) 
-		if (lv--.current())
-			moveItem(lv.current()); 
-	
-	if (!found)
-		moveItem(listView()->lastItem());
-		
-}
-*/
