@@ -26,6 +26,7 @@
 #include <qtooltip.h> 
 #include <qtoolbutton.h>
 #include <qobjectlist.h>
+#include <qspinbox.h>
 
 #ifdef Q_OS_MACX
 #include <CoreFoundation/CFString.h>
@@ -128,7 +129,7 @@ PreferencesDialog::PreferencesDialog(QWidget* parent,  const char* name, bool mo
 	ComboBox_codec->insertItem("");
 	// The rest by name
 	QTextCodec *codec;
-	for(int i = 0; codec = QTextCodec::codecForIndex(i); ++i)
+	for(int i = 0; (codec = QTextCodec::codecForIndex(i)); ++i)
 		ComboBox_codec->insertItem(codec->name());
 }
 
@@ -765,3 +766,15 @@ void PreferencesDialog::slot_delete_button()
 	}
 	
 }
+
+
+void PreferencesDialog::slot_main_time_changed(int n)
+{
+	timeSpin_Nmatch->setMinValue(n);
+}
+
+
+void PreferencesDialog::slot_BY_time_changed(int n)
+{
+	BYSpin_Nmatch->setMinValue(n);
+}
