@@ -11,6 +11,7 @@
 #include "qobject.h"
 #include "defines.h"
 #include <qptrlist.h>
+#include "searchpath.h"
 
 #ifdef Q_WS_WIN
 #include <qfiledialog.h>
@@ -79,6 +80,8 @@ private:
 	QSound *enterSound;
 	QSound *leaveSound;
 	QSound *connectSound;
+	QSound *retrieveSound(const char *, SearchPath&);
+	bool   soundsFound();
 };
 
 #endif
