@@ -343,8 +343,16 @@ bool qGoIF::parse_move(int src, GameInfo* gi, Game* g, QString txt)
 				qgobrd,
 				SLOT(slot_ttMark(bool)));
 
+			if (src == 2)
+			{
+				qgobrd->set_sentmovescmd(true);
+				emit signal_sendcommand("games " + txt, false);
+				emit signal_sendcommand("moves " + txt, false);
+				emit signal_sendcommand("all " + txt, false);
+			}
+
 			// for own games send "games" cmd to get full info
-			if (src == 3 || src == 4 || src == 13 || src == 14)
+			if (src == 3 || src == 4 || src == 13 || src == 14 )//|| src == 0)
 			{
 				connect(qgobrd->get_win()->getInterfaceHandler()->normalTools->pb_timeBlack,
 					SIGNAL(clicked()),
@@ -355,7 +363,7 @@ bool qGoIF::parse_move(int src, GameInfo* gi, Game* g, QString txt)
 					qgobrd,
 					SLOT(slot_addtimePauseW()));
 
-				if (src == 13 || src == 14)// || src== 0)
+				if (src == 13 || src == 14 )//|| src== 0)
 				{
 					// src changed from 1 to 3/4
 					qgobrd->set_sentmovescmd(true);
@@ -785,9 +793,9 @@ void qGoIF::slot_computer_game(QNewGameDlg * dlg)
 }
 
 // game to observe (mouse click)
-bool qGoIF::set_observe(QString gameno)
+void qGoIF::set_observe(const QString& gameno)
 {
-	return parse_move(2, 0, 0, gameno);
+	parse_move(2, 0, 0, gameno);
 }
 
 // remove all boards
