@@ -80,6 +80,13 @@ Setting::Setting() : Misc<QString>()
   
   	// defaults:
 	writeBoolEntry("USE_NMATCH", true);
+	writeBoolEntry("NMATCH_BLACK", true);
+	writeBoolEntry("NMATCH_WHITE", true);
+	writeBoolEntry("NMATCH_NIGIRI", true);
+	writeIntEntry("NMATCH_HANDICAP", 9);
+	writeIntEntry("NMATCH_MAIN_TIME", 100);
+	writeIntEntry("NMATCH_BYO_TIME", 100);
+
 	writeBoolEntry("SIDEBAR", true);
 	writeBoolEntry("BOARD_COORDS", true);
 	writeBoolEntry("SGF_BOARD_COORDS", false);
@@ -94,8 +101,8 @@ Setting::Setting() : Misc<QString>()
 	writeEntry("SKIN", "");
 	writeEntry("SKIN_TABLE", "");
 	writeBoolEntry("TOOLTIPS", true);
-	writeBoolEntry("STONES_SHADOW", true);
-	writeBoolEntry("STONES_SHELLS", true);
+	//writeBoolEntry("STONES_SHADOW", true);
+	//writeBoolEntry("STONES_SHELLS", true);
 	writeBoolEntry("VAR_FONT", true);
 	writeBoolEntry("SOUND_STONE", true);
 	writeBoolEntry("SOUND_AUTOPLAY", true);
@@ -117,9 +124,10 @@ Setting::Setting() : Misc<QString>()
 	writeIntEntry("BY_TIMER", 10);
 	writeIntEntry("COMPUTER_SIZE", 19);
 	writeEntry("LAST_DIR", QDir::homeDirPath());
-#ifdef Q_OS_MACX
+//#ifdef Q_OS_MACX
 	writeBoolEntry("REM_DIR", true);
-#endif
+	writeIntEntry("STONES_LOOK", 3);
+//#endif
 
 	// Default ASCII import charset
 	charset = new ASCII_Import();
@@ -147,6 +155,8 @@ Setting::Setting() : Misc<QString>()
 	cw = 0;
 	program_dir = QString();
 
+	nmatch_settings_modified=false;
+
 #ifdef Q_WS_WIN
 	applicationPath = getApplicationPath();
 #endif
