@@ -11,12 +11,12 @@
 class Stone : public QCanvasSprite
 {
 public:
-	Stone(QCanvasPixmapArray *a, QCanvas *canvas, StoneColor c, int x, int y, int numberOfImages=8);
-	~Stone() {}
+	Stone(QCanvasPixmapArray *a, QCanvas *canvas, StoneColor c, int x, int y, int numberOfImages=WHITE_STONES_NB, bool has_shadow=false);
+	~Stone() ;
 	
 	StoneColor getColor() const { return color; }
 	void setColor(StoneColor c=stoneBlack);
-  void toggleOneColorGo(bool oneColor) ;
+	void toggleOneColorGo(bool oneColor) ;
 	int rtti() const { return RTTI_STONE; }
 	int posX() const { return myX; }
 	int posY() const { return myY; }
@@ -26,8 +26,15 @@ public:
 	bool isSeki() const { return seki; }
 	void setSeki(bool b=true) { seki = b; dead = false; }
 	
+	void setX(double x);
+	void setY(double y);
+	void show();
+	void hide();
+	
 	bool checked;
 	
+	QCanvasSprite *shadow;
+	
 private:
 	StoneColor color;
 	int myX, myY;
