@@ -39,7 +39,7 @@ void StoneHandler::clearData()
 }
 
 
-bool StoneHandler::addStone(Stone *stone, bool toAdd, bool doCheck, Matrix *m)  //SL added eb 8
+bool StoneHandler::addStone(Stone *stone, bool toAdd, bool doCheck, Matrix *m, bool koStone)
 {
 //	CHECK_PTR(stone);
 //	CHECK_PTR(m);
@@ -48,8 +48,7 @@ bool StoneHandler::addStone(Stone *stone, bool toAdd, bool doCheck, Matrix *m)
 		stones->insert(Matrix::coordsToKey(stone->posX(), stone->posY()), stone);
 	
 	if (doCheck)
-//  return checkPosition(stone);
-		return checkPosition(stone, m);     //SL added eb 8
+		return checkPosition(stone, m, koStone);
 	
 	return true;
 }
@@ -100,7 +99,7 @@ int StoneHandler::hasStone(int x, int y)
 }
 
 //bool StoneHandler::checkPosition(Stone *stone)
-bool StoneHandler::checkPosition(Stone *stone, Matrix *m)
+bool StoneHandler::checkPosition(Stone *stone, Matrix *m, bool koStone)
 {
 	//CHECK_PTR(stone);
  // CHECK_PTR(m); // SL added eb 8
@@ -203,6 +202,15 @@ bool StoneHandler::checkPosition(Stone *stone, Matrix *m)
 				return false;
 			}
 			
+			//was it a forbidden ko move ?
+			if ((tmp->count() == 1) && koStone && ((countLiberties(active, m) == 0)))
+			{
+				active->debug();
+				groups->remove(groups->findRef(active));
+				removeStone(stone->posX(), stone->posY(), false);
+				return false ;
+			}
+
 			int stoneCounter = 0;
 			
 			// Erase the stones of this group from the stones table.
@@ -644,9 +652,15 @@ bool StoneHandler::removeDeadGroup(int x, int y, int &caps, StoneColor &col, boo
 		CHECK_PTR(s);
 		s->setDead(dead);
 		if (dead)
+		{
 			s->setSequence(boardHandler->board->getImageHandler()->getGhostPixmaps());
+			s->shadow->hide();
+		}
 		else
+		{
 			s->setSequence(boardHandler->board->getImageHandler()->getStonePixmaps());
+			s->shadow->show();
+		}
 	}
 	
 	delete g;
@@ -678,9 +692,15 @@ bool StoneHandler::markSekiGroup(int x, int y, int &caps, StoneColor &col, bool
 			caps ++;
 		s->setSeki(seki);
 		if (seki)
+		{
 			s->setSequence(boardHandler->board->getImageHandler()->getGhostPixmaps());
+			s->shadow->hide();
+		}	
 		else
+		{
 			s->setSequence(boardHandler->board->getImageHandler()->getStonePixmaps());
+			s->shadow->show();
+		}
 	}
 	
 	delete g;
@@ -701,6 +721,7 @@ void StoneHandler::removeDeadMarks()
 			s->setDead(false);
 			s->setSeki(false);
 			s->setSequence(boardHandler->board->getImageHandler()->getStonePixmaps());
+			s->shadow->show();
 		}
 		++it;
 	}
