@@ -218,9 +218,9 @@ void ClientWindow::slot_game(Game* g)
 			{
 				lv = new GamesTableItem(ListView_games,
 					g->nr,
-					g->wname,
+					" " + g->wname,
 					g->wrank,
-					g->bname,
+					" " + g->bname,
 					g->brank,
 					g->mv,
 					g->Sz,
@@ -234,9 +234,9 @@ void ClientWindow::slot_game(Game* g)
 			{
 				lv = new GamesTableItem(ListView_games,
 					g->nr,
-					g->wname,
+					" " + g->wname,
 					g->wrank,
-					g->bname,
+					" " + g->bname,
 					g->brank,
 					g->mv,
 					g->Sz);
@@ -403,8 +403,10 @@ void ClientWindow::slot_player(Player *p, bool cmdplayers)
 							lvi->setText(8, p->won);
 							lvi->setText(9, p->lost);
 							lvi->setText(10, p->country);
-							lvi->setText(11, p->language);
+							lvi->setText(11, p->nmatch_settings);
 						}
+						lvi->set_nmatchSettings(p);					
+						//lvi->nmatch = p->nmatch;
 
 						lvi->ownRepaint();
 					}
@@ -501,7 +503,7 @@ void ClientWindow::slot_player(Player *p, bool cmdplayers)
 		// from WHO command or {... has connected}
 		if (extUserInfo && myAccount->get_gsname() == IGS)
 		{
-			lv = new PlayerTableItem(ListView_players,
+			PlayerTableItem *lv1 = new PlayerTableItem(ListView_players,
 					p->info,
 					p->name,
 					p->rank,
@@ -513,12 +515,13 @@ void ClientWindow::slot_player(Player *p, bool cmdplayers)
 					p->won,
 					p->lost,
 					p->country,
-					p->language);
-			lv.current()->setText(12, rkToKey(p->rank) + p->name.lower());
+					p->nmatch_settings);
+			lv1->setText(12, rkToKey(p->rank) + p->name.lower());
+			lv1->set_nmatchSettings(p);
 		}
 		else
 		{
-			lv = new PlayerTableItem(ListView_players,
+			PlayerTableItem *lv1 = new PlayerTableItem(ListView_players,
 					p->info,
 					p->name,
 					p->rank,
@@ -526,7 +529,8 @@ void ClientWindow::slot_player(Player *p, bool cmdplayers)
 					p->obs_str,
 					p->idle,
 					mark);
-			lv.current()->setText(12, rkToKey(p->rank) + p->name.lower());
+			lv1->setText(12, rkToKey(p->rank) + p->name.lower());
+			lv1->set_nmatchSettings(p);
 		}
 
 		// increase number of players
@@ -926,13 +930,14 @@ GSName Account::get_gsname()
  *   Host - Class to save Host info
  */
 
-Host::Host(const QString &title, const QString &host, const unsigned int port, const QString &login, const QString &pass)
+Host::Host(const QString &title, const QString &host, const unsigned int port, const QString &login, const QString &pass, const QString &cod)
 {
 	t = title;
 	h = host;
 	pt = port;
 	lg = login;
 	pw = pass;
+	cdc = cod;
 }
 
 /*
@@ -980,51 +985,30 @@ int ChannelList::compareItems(Item d1, Item d2)
 
 int Talk::counter = 0;
 
-Talk::Talk(const QString &playername, QWidget * /* parent */, bool /*isplayer*/)
+Talk::Talk(const QString &playername, QWidget * /* parent */, bool isplayer)
 	: TalkGui()
 {
 	name = playername;
 
 	// create a new tab
-	/*widget = new QWidget(parent);
-	TalkDialogWidgetLayout = new QGridLayout(widget); 
-	TalkDialogWidgetLayout->setSpacing(6);
-	TalkDialogWidgetLayout->setMargin(0);  */
-
-	//MultiLineEdit1 = new QTextEdit(widget, "MultiLineEdit1_" + QString::number(++counter));
 	QString s = "MultiLineEdit1_" + QString::number(++counter);
 	MultiLineEdit1->setName(s.ascii()) ;
   
-	MultiLineEdit1->setCurrentFont(setting->fontComments); //eb16
-	/*MultiLineEdit1->setProperty("focusPolicy", (int)QTextEdit::NoFocus); //eb16
-	MultiLineEdit1->setProperty("wordWrap", (int)QTextEdit::WidgetWidth);//eb16
-	MultiLineEdit1->setProperty("readOnly", QVariant( TRUE, 0));
+	MultiLineEdit1->setCurrentFont(setting->fontComments); 
 
-	TalkDialogWidgetLayout->addWidget(MultiLineEdit1, 0, 0);
-  */
-	//LineEdit1 = new QLineEdit(widget, "LineEdit1_" + QString::number(counter));
 	s = "LineEdit1_" + QString::number(++counter);
 	LineEdit1->setName(s.ascii());
 	LineEdit1->setFont(setting->fontComments);
 
-	// do not add a button for shouts* tab
-	if (name.find('*') != -1)
+	// do not add a button for shouts* or channels tab
+	if ( (name.find('*') != -1) || (!isplayer))
 	{
-		/*buttonLayout = new QHBoxLayout();
-		buttonLayout->addWidget(LineEdit1);
-		pb_releaseTalkTab = new QPushButton(tr("close"), widget, "SkipAllTalkTabs");
-		connect(pb_releaseTalkTab, SIGNAL(clicked()), this, SLOT(slot_pbRelTab()));
 
-		buttonLayout->addWidget(pb_releaseTalkTab);
-		TalkDialogWidgetLayout->addItem(buttonLayout, 1, 0);
-    */
-	delete pb_releaseTalkTab;
-	delete pb_match;
-	delete stats_layout;
+		delete pb_releaseTalkTab;
+		delete pb_match;
+		delete stats_layout;
 	}
-//	else
-//		TalkDialogWidgetLayout->addWidget(LineEdit1, 1, 0 );
-   
+	
 }
 
 Talk::~Talk()
