@@ -18,7 +18,7 @@ class TelnetInterface : public QObject
 public:
 	TelnetInterface();
 	~TelnetInterface();
-	static void callback(const char *s, uint i=0);
+	static void callback(QString);
 
 signals:
 	void textRecieved(const QString&);
@@ -35,7 +35,7 @@ public:
 	~TelnetConnection();
 
 	void sendTextFromApp(const QString&);
-	void setHost(const QString, const QString, const QString, unsigned int);
+	void setHost(const QString, const QString, const QString, unsigned int, const QString);
 
 public slots:
 	void slotHostConnect();
@@ -43,7 +43,7 @@ public slots:
 	void slotHostQuit();
 
 private:
-	QString host, loginName, password;
+	QString host, loginName, password, codec;
 	unsigned int port;
 
 	IGSInterface *igsInterface;
