@@ -1,4 +1,4 @@
-/* $Header: /cvsroot/qgo/qgo/src/wavfile.c,v 1.6 2004/10/30 23:36:45 yfh2 Exp $
+/* $Header: /cvsroot/qgo/qgo/src/wavfile.c,v 1.8 2005/09/08 18:46:31 yfh2 Exp $
  * Copyright: wavfile.c (c) Erik de Castro Lopo  erikd@zip.com.au
  *
  * wavfile.c - Functions for reading and writing MS-Windoze .WAV files.
@@ -43,7 +43,7 @@
 
 #ifdef __linux__
 
-static const char rcsid[] = "@(#)wavfile.c $Revision: 1.6 $";
+static const char rcsid[] = "@(#)wavfile.c $Revision: 1.8 $";
 
 
 #include <stdio.h>
@@ -65,6 +65,14 @@ static const char rcsid[] = "@(#)wavfile.c $Revision: 1.6 $";
 
 
 
+#if WORDS_BIGENDIAN
+#define SwapLE16(x) ((((u_int16_t)x)<<8)|(((u_int16_t)x)>>8))
+#define SwapLE32(x) ((((u_int32_t)x)<<24)|((((u_int32_t)x)<<8)&0x00FF0000) \
+                     |((((u_int32_t)x)>>8)&0x0000FF00)|(((u_int32_t)x)>>24))
+#else
+#define SwapLE16(x) (x)
+#define SwapLE32(x) (x)
+#endif
 
 
 #include "wavplay.h"
@@ -79,29 +87,29 @@ static const char rcsid[] = "@(#)wavfile.c $Revision: 1.6 $";
 
 
 typedef  struct
-{	u_long     dwSize ;
-	u_short    wFormatTag ;
-	u_short    wChannels ;
-	u_long     dwSamplesPerSec ;
-	u_long     dwAvgBytesPerSec ;
-	u_short    wBlockAlign ;
-	u_short    wBitsPerSample ;
+{	u_int32_t  dwSize ;
+	u_int16_t  wFormatTag ;
+	u_int16_t  wChannels ;
+	u_int32_t  dwSamplesPerSec ;
+	u_int32_t  dwAvgBytesPerSec ;
+	u_int16_t  wBlockAlign ;
+	u_int16_t  wBitsPerSample ;
 } WAVEFORMAT ;
 
 typedef  struct
 {	char    	RiffID [4] ;
-	u_long    	RiffSize ;
+	u_int32_t 	RiffSize ;
 	char    	WaveID [4] ;
 	char    	FmtID  [4] ;
-	u_long    	FmtSize ;
-	u_short   	wFormatTag ;
-	u_short   	nChannels ;
-	u_long		nSamplesPerSec ;
-	u_long		nAvgBytesPerSec ;
-	u_short		nBlockAlign ;
-	u_short		wBitsPerSample ;
+	u_int32_t  	FmtSize ;
+	u_int16_t 	wFormatTag ;
+	u_int16_t  	nChannels ;
+	u_int32_t	nSamplesPerSec ;
+	u_int32_t	nAvgBytesPerSec ;
+	u_int16_t	nBlockAlign ;
+	u_int16_t	wBitsPerSample ;
 	char		DataID [4] ;
-	u_long		nDataBytes ;
+	u_int32_t	nDataBytes ;
 } WAVE_HEADER ;
 
 /*=================================================================================================*/
@@ -190,7 +198,14 @@ int  WaveReadHeader  (int wavefile, int* channels, u_long* samplerate, int* samp
 
 	ptr += 4 ;	/* Move past "fmt ".*/
 	memcpy (&waveformat, ptr, sizeof (WAVEFORMAT)) ;
-
+	waveformat.dwSize = SwapLE32(waveformat.dwSize);
+	waveformat.wFormatTag = SwapLE16(waveformat.wFormatTag) ;
+	waveformat.wChannels = SwapLE16(waveformat.wChannels) ;
+	waveformat.dwSamplesPerSec = SwapLE32(waveformat.dwSamplesPerSec) ;
+	waveformat.dwAvgBytesPerSec = SwapLE32(waveformat.dwAvgBytesPerSec) ;
+	waveformat.wBlockAlign = SwapLE16(waveformat.wBlockAlign) ;
+	waveformat.wBitsPerSample = SwapLE16(waveformat.wBitsPerSample) ;
+	
 	if (waveformat.dwSize < (sizeof (WAVEFORMAT) - sizeof (u_long))) {
 		err("Bad format: Bad fmt size");			/* wwg: report error */
 		return  WR_BADFORMATSIZE ;
