@@ -1,4 +1,4 @@
-/* $Header: /cvsroot/qgo/qgo/src/wavplay.h,v 1.3 2004/10/30 23:35:00 yfh2 Exp $
+/* $Header: /cvsroot/qgo/qgo/src/wavplay.h,v 1.4 2006/11/06 07:09:45 yfh2 Exp $
  * Warren W. Gay VE3WWG		Sun Feb 16 18:17:17 1997
  *
  * WAVPLAY OPTION SETTINGS:
@@ -62,7 +62,7 @@
 
 
 #ifndef _wavplay_h_
-#define _wavplay_h_ "$Id: wavplay.h,v 1.3 2004/10/30 23:35:00 yfh2 Exp $"
+#define _wavplay_h_ "$Id: wavplay.h,v 1.4 2006/11/06 07:09:45 yfh2 Exp $"
 
 #define WAVPLAY_VERSION		"1.4"
 
@@ -74,20 +74,7 @@
 #include <pthread.h>
 
 
-/*
- * From the man page semctl(2) :
- */
-#if defined(__GNU_LIBRARY__) && !defined(_SEM_SEMUN_UNDEFINED)
-	/* union semun is defined by including <sys/sem.h> */
-#else
-	/* according to X/OPEN we have to define it ourselves */
-	union semun {
-		int		val;		/* value for SETVAL */
-		struct semid_ds	*buf;		/* buffer for IPC_STAT, IPC_SET */
-		unsigned short	*array;		/* array for GETALL, SETALL */
-		struct seminfo	*__buf;		/* buffer for IPC_INFO */
-	};
-#endif
+
 
 typedef void (*ErrFunc)(const char *format,va_list ap);
 
